@@ -51,6 +51,8 @@
 
 #define DEBUG_OUTPUT
 #undef DEBUG_OUTPUT
+#define DEBUG_EVENT_OUTPUT
+#undef DEBUG_EVENT_OUTPUT
 
 /**
 Globals
@@ -101,9 +103,22 @@ MainWindow::MainWindow(QWidget *parent) :
 
   connect(this->mainButton, SIGNAL(clicked()), this, SLOT(mainButtonHandler()));
 
+#ifdef DO_SCREEN_HANDLING
+  dBusInterface = new QDBusInterface(MCE_SERVICE, MCE_REQUEST_PATH,
+                                     MCE_REQUEST_IF, dBusConnection, this);
+
+  dBusConnection.connect(MCE_SERVICE, MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+                         MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(const QDBusMessage &)));
+
+  dBusInterface->callWithCallback(MCE_DISPLAY_STATUS_GET, QList<QVariant>(), this,
+                                    SLOT(setDisplayState(QString)),
+                                    SLOT(displayStateError(QDBusError)));
+#endif
+
   /**
     Initial values
   */
+  setFocusPolicy(Qt::StrongFocus);
   changeNumberOfLines(8);
   changeFontSize(30);
   isStartStopModeActive = false;
@@ -176,6 +191,7 @@ int MainWindow::resetCounters()
 {
   hitCount=-1;
   updateTime();
+  overallTime.stop();
   return EXIT_SUCCESS;
 }
 
@@ -558,6 +574,10 @@ int MainWindow::getScreensaverDisabledFlag()
 {
   return isScreenSaverDisabled;
 }
+int MainWindow::getFullscreenFlag()
+{
+  return (windowState() & Qt::WindowFullScreen);
+}
 
 /*
 Functions to set ui specific behavior flags
@@ -601,9 +621,26 @@ int MainWindow::setScreensaverDisabled(int n)
   isScreenSaverDisabled = !bool(n); //inverted logic for toggle function
   actionDisableScreensaver->setChecked(bool(n));
   toggleDisableScreensaver();
-#endif
   return isScreenSaverDisabled;
+#endif
+  return n;
 }
+int MainWindow::setFullscreen(int n)
+{
+  if(n > 0)
+  {
+    fsExitButton->show();
+    showFullScreen();
+    action_Fullscreen->setChecked(true);
+  }
+  else
+  {
+    action_Fullscreen->setChecked(false);
+    showNormal();
+  }
+  return getFullscreenFlag();
+}
+
 
 MainWindow::StringFunctionMap* MainWindow::getSfm()
 {
@@ -630,7 +667,10 @@ MainWindow::StringFunctionMap* MainWindow::getSfm()
 {"disableScreensaver",
  &MainWindow::getScreensaverDisabledFlag,
  &MainWindow::setScreensaverDisabled},
-{"",
+{"fullscreen",
+ &MainWindow::getFullscreenFlag,
+ &MainWindow::setFullscreen},
+ {"",
  NULL,
  NULL}
   };
@@ -1038,10 +1078,9 @@ void MainWindow::resetProgram()
 void MainWindow::resetProgramAndFullscreen()
 {
   resetProgram();
-  action_Fullscreen->trigger();
+  setFullscreen(1);
 }
 
-
 /**
 Function to save generated values to a file directly without viewing
 Currently unused.
@@ -1108,19 +1147,78 @@ void MainWindow::showFullList()
 
 void MainWindow::showFullScreenHandler()
 {
-  bool isFullScreen = windowState() & Qt::WindowFullScreen;
-  if (isFullScreen)
-  {
-    showNormal();
-  }
-  else
-  {
-    showFullScreen();
-    fsExitButton->show();
-  }
+  setFullscreen(!getFullscreenFlag());
 }
 
 void MainWindow::slotFullscreenExit()
 {
   action_Fullscreen->trigger();
 }
+
+
+#ifdef DO_SCREEN_HANDLING
+/*******************************************************************************
+  Handling the screen state (turning on/off counting/screen refresh)
+  *****************************************************************************/
+void MainWindow::displayStateChanged(const QDBusMessage &message)
+{
+    QString state = message.arguments().at(0).toString();
+    setDisplayState(state);
+}
+
+void MainWindow::displayStateError(const QDBusError &error)
+{
+
+}
+
+void MainWindow::setDisplayState(const QString &state)
+{
+  if (!state.isEmpty())
+  {
+    if (state == MCE_DISPLAY_ON_STRING) //display on
+    {
+      if(timer && !timer->isActive() && overallTime.isActive())
+      {
+        timer->start();
+      }
+    }
+    else if (state == MCE_DISPLAY_OFF_STRING) //Display off
+    {
+      if(timer && timer->isActive() && overallTime.isActive())
+      {
+        timer->stop();
+      }
+    }
+  }
+}
+#endif
+
+/*******************************************************************************
+  Modified Events
+
+  Unfortuneately the events show/hide are never called in maemo. So they only
+  make sense for the desktop version.
+  *****************************************************************************/
+void MainWindow::showEvent(QShowEvent *e)
+{
+#ifdef DEBUG_EVENT_OUTPUT
+  std::cout << __func__ << std::endl;
+#endif
+  if(timer && !timer->isActive() && overallTime.isActive())
+  {
+    timer->start();
+  }
+  QWidget::showEvent(e);
+}
+
+void MainWindow::hideEvent(QHideEvent *e)
+{
+#ifdef DEBUG_EVENT_OUTPUT
+  std::cout << __func__ << std::endl;
+#endif
+  if(timer && timer->isActive() && overallTime.isActive())
+  {
+    timer->stop();
+  }
+  QWidget::hideEvent(e);
+}
