@@ -29,6 +29,18 @@
 #include "timekeeper.h"
 #include "releaseinformation.hpp"
 
+#ifdef Q_WS_MAEMO_5
+#define DO_SCREEN_HANDLING
+#ifdef DO_SCREEN_HANDLING
+#include <mce/dbus-names.h>
+#include <mce/mode-names.h>
+//#include <QtDBus/QDBusConnection>
+#include <QtDBus/QtDBus>
+
+static QDBusConnection dBusConnection = QDBusConnection::systemBus();
+#endif
+#endif
+
 //QTM_USE_NAMESPACE
 
 class MainWindow : public QMainWindow
@@ -64,6 +76,13 @@ public:
 #ifdef Q_WS_MAEMO_5
     void toggleDisableScreensaver();
 #endif
+#ifdef DO_SCREEN_HANDLING
+    void displayStateChanged(const QDBusMessage &message);
+    void displayStateError(const QDBusError &error);
+    void setDisplayState(const QString &state);
+#endif
+    void showEvent(QShowEvent *e);
+    void hideEvent(QHideEvent *e);
 
 private:
     /* Datatypes */
@@ -101,6 +120,7 @@ private:
     int getShowFullDateFlag();
     int getStartPauseFlag();
     int getScreensaverDisabledFlag();
+    int getFullscreenFlag();
     //setting
     int setNumberOfLines(int);
     int setFontSize(int);
@@ -109,6 +129,7 @@ private:
     int setShowFullDateFlag(int);
     int setStartPauseFlag(int);
     int setScreensaverDisabled(int);
+    int setFullscreen(int);
 
     StringFunctionMap* getSfm();
 
@@ -162,6 +183,9 @@ private:
     bool isScreenSaverDisabled;
 
     StringFunctionMap *sfm;
+#ifdef DO_SCREEN_HANDLING
+    QDBusInterface *dBusInterface;
+#endif
 };
 
 #endif // MAINWINDOW_H
